# -*- coding: utf-8 -*-
## GrufSpaces
## Group environments for elaborating and exchanging information
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""
pas allows access to getLocalRolesForDisplay with permission Manage properties
it's insufficient for grufspaces mailing : we add GroupSpace_sendMailPermission
"""

import logging
from Products.PluggableAuthService.PluggableAuthService import PluggableAuthService
from AccessControl import Unauthorized, getSecurityManager

from Products.GrufSpaces.permissions import GroupSpace_sendMailPermission

LOG = logging.getLogger("GrufSpaces")

try:
    from Products.PlonePAS import pas
    LOG.info("PlonePAS patched by GrufSpaces")
    patch = True

except:
    patch = False
    pass

PATCHED1 = False

if patch and not PATCHED1:

    def getLocalRolesForDisplay(self, object):
        """This is used for plone's local roles display

        This method returns a tuple (massagedUsername, roles, userType,
        actualUserName).  This method is protected by the 'access content
        information' permission. We may change that if it's too
        permissive...

        A GRUF method originally.
        """
        # Perform security check on destination object
        try:
            return pas.getLocalRolesForDisplay(self, object)
        except Unauthorized:
            if not getSecurityManager().checkPermission(GroupSpace_sendMailPermission,
                                                        object):
                raise Unauthorized(name = "getLocalRolesForDisplay")

            else:
                return self._getLocalRolesForDisplay(object)

    PluggableAuthService.getLocalRolesForDisplay = getLocalRolesForDisplay

    LOG.info("Grufspaces patched to allow access to getLocalRolesForDisplay with send mail permission")

PATCHED1 = True




"""
groupadmin can change all local roles except manager
"""

from Products.CMFPlone.MembershipTool import MembershipTool

PATCHED2 = False

old_getCandidateLocalRoles = MembershipTool.getCandidateLocalRoles

if not PATCHED2:
    def getCandidateLocalRoles(self, obj):
        member = self.getAuthenticatedMember()
        # Use getRolesInContext as someone may be a local manager
        if 'GroupAdmin' in member.getRolesInContext(obj):
            local_roles = [r for r in obj.valid_roles() if r not in
                            ('Anonymous', 'Authenticated', 'Shared', 'Manager')]
            local_roles.sort()
            return local_roles
        else:
            return old_getCandidateLocalRoles(self, obj)
    LOG.info("Grufspaces patched to allow groupadmin to change all local roles")

    MembershipTool.getCandidateLocalRoles = getCandidateLocalRoles
PATCHED2 = True
